#!/usr/bin/ksh
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#

# buildpkg.sh: This script builds a Solaris PKG from the source tree
#              provided.

LAYOUT=AIX
TEMPDIR=/var/tmp/$USER/httpd-root
rm -rf $TEMPDIR

## with-z is needed to supply the include file, not just the archive
## so depends on libz stuff being installed in /opt/aixtools
## will update to fix this hard dependancy!
## dependancy on /opt/aixtools is removed by installing the rpm-devel*.rpm
## strange interaction between install and libtool requires a regular install
## for all the links to succeed in the TEMPDIR

# > nohup.out
# ./configure \
# 	--with-z=/opt/aixtools \
# 	--enable-layout=$LAYOUT \
# 	--enable-module=so \
# 	--enable-proxy \
# 	--enable-cache \
# 	--enable-disk-cache \
# 	--with-mpm=worker \
# 	--enable-mods-shared=all | tee nohup.out

# nohup make

make install > install.log
make install DESTDIR=$TEMPDIR

# will make use of the pkginfo data as input for mkinstallp template
cp build/pkg/pkginfo $TEMPDIR

current=`pwd`
cd $TEMPDIR
mkdir .info

## quick and dirty initially - no seperate filesets for man pages, documents, etc.

$current/build/pkg/aixproto.ksh $current

cd $current

rm -rf $TEMPDIR
ls -ltr build/pkg
